# level 3

What to do with so much information?
Only some of it is actually useful.
The information you seek may be in the middle
Of places that have a SECRET at the end.
And the way forward may be hidden as well.
